@@ -31,6 +31,7 @@
 #include <libgnomecanvasmm/pixbuf.h>
 #include <libgnomecanvasmm/bpath.h>
 #include <libgnomecanvasmm/path-def.h>
+#include <libgnomecanvasmm/properties.h>
 
 Primitives::Primitives(bool aa)
 : Gtk::VBox(false, 4)
@@ -41,28 +42,28 @@ Primitives::Primitives(bool aa)
       = manage(new Gtk::Label("Drag an item with button 1.  Click button 2 on an item to lower it,\n"
                               "or button 3 to raise it.  Shift+click with buttons 2 or 3 to send\n"
                               "an item to the bottom or top, respectively."));
-  pack_start(*label);
+  pack_start(*label, Gtk::PACK_SHRINK);
   
   Gtk::HBox* hbox = manage(new Gtk::HBox(false, 4));
-  pack_start(*hbox, true, true);
+  pack_start(*hbox, Gtk::PACK_SHRINK);
   
-  hbox->pack_start(*manage(new Gtk::Label("Zoom:")), false, false);
+  hbox->pack_start(*manage(new Gtk::Label("Zoom:")), Gtk::PACK_SHRINK);
   
   Gtk::Adjustment* spin_adj 
       = manage(new Gtk::Adjustment(1.00, 0.05, 5.00, 0.05, 0.50, 0.50));
   Gtk::SpinButton* spin = manage(new Gtk::SpinButton(*spin_adj, 1.0, 2));
-  hbox->pack_start(*spin, false, false);
+  hbox->pack_start(*spin, Gtk::PACK_SHRINK);
   
   Gtk::Table* table = manage(new Gtk::Table(2, 2, false));
-  pack_start(*table, true, true);
+  pack_start(*table);
   table->set_row_spacings(4);
   table->set_col_spacings(4);
   
   Gtk::Frame* frame = manage(new Gtk::Frame());
   frame->set_shadow_type(Gtk::SHADOW_IN);
   table->attach(*frame, 0, 1, 0, 1, 
-                Gtk::AttachOptions(Gtk::EXPAND | Gtk::FILL | Gtk::SHRINK),
-                Gtk::AttachOptions(Gtk::EXPAND | Gtk::FILL | Gtk::SHRINK));
+                Gtk::AttachOptions(Gtk::EXPAND | Gtk::FILL | Gtk::PACK_SHRINK),
+                Gtk::AttachOptions(Gtk::EXPAND | Gtk::FILL | Gtk::PACK_SHRINK));
   
   Gnome::Canvas::Canvas* canvas;
   if(aa == true) {
@@ -70,25 +71,26 @@ Primitives::Primitives(bool aa)
   } else {
       canvas = manage(new Gnome::Canvas::Canvas());
   }
-  canvas->set_flags(GTK_CAN_FOCUS);
+  canvas->set_flags(Gtk::CAN_FOCUS);
   canvas->grab_focus();
   frame->add(*canvas);
   canvas->set_size_request(600, 450);
   canvas->set_scroll_region(0, 0, 600, 450);
+  canvas->set_center_scroll_region(false);
   canvas->signal_key_press_event()
       .connect(bind(slot(*this, &Primitives::on_key_press), canvas));
   
   Gtk::HScrollbar* hscroll 
       = manage(new Gtk::HScrollbar(*canvas->get_hadjustment()));
   table->attach(*hscroll, 0, 1, 1, 2,
-                Gtk::AttachOptions(Gtk::EXPAND | Gtk::FILL | Gtk::SHRINK),
+                Gtk::AttachOptions(Gtk::EXPAND | Gtk::FILL | Gtk::PACK_SHRINK),
                 Gtk::AttachOptions(Gtk::FILL));
   
   Gtk::VScrollbar* vscroll 
       = manage(new Gtk::VScrollbar(*canvas->get_vadjustment()));
   table->attach(*vscroll, 1, 2, 0, 1,
                 Gtk::AttachOptions(Gtk::FILL),
-                Gtk::AttachOptions(Gtk::EXPAND | Gtk::FILL | Gtk::SHRINK));
+                Gtk::AttachOptions(Gtk::EXPAND | Gtk::FILL | Gtk::PACK_SHRINK));
   
   spin_adj->signal_value_changed()
       .connect(bind(slot(*this, &Primitives::on_zoom_changed),
@@ -463,16 +465,29 @@ Primitives::setup_texts(Gnome::Canvas::Group& root)
   
   text = manage(new Gnome::Canvas::Text(*make_anchor(root, 
                                                      590.0, 140.0)));
-  text->property_text() = "Clipped text\nClipped text\nClipped text\nClipped text\nClipped text\nClipped text";
-  text->property_x() = 0.0;
-  text->property_y() = 0.0;
-  text->property_font() = "Sans 12";
-  text->property_anchor() = Gtk::ANCHOR_SE;
-  text->property_clip() = true;
-  text->property_clip_width() = 50.0;
-  text->property_clip_height() = 55.0;
-  text->property_x_offset() = 10.0;
-  text->property_fill_color() = "darkgreen";
+
+//   text->property_text() = "Clipped text\nClipped text\nClipped text\nClipped text\nClipped text\nClipped text";
+//   text->property_x() = 0.0;
+//   text->property_y() = 0.0;
+//   text->property_font() = "Sans 12";
+//   text->property_anchor() = Gtk::ANCHOR_SE;
+//   text->property_clip() = true;
+//   text->property_clip_width() = 50.0;
+//   text->property_clip_height() = 55.0;
+//   text->property_x_offset() = 10.0;
+//   text->property_fill_color() = "darkgreen";
+
+  // example for setting values using the properties mechanism
+  *text << Gnome::Canvas::Properties::text ("Clipped text\nClipped text\nClipped text\nClipped text\nClipped text\nClipped text")
+        << Gnome::Canvas::Properties::x (0.0)
+        << Gnome::Canvas::Properties::y (0.0)
+        << Gnome::Canvas::Properties::font ("Sans 12")
+        << Gnome::Canvas::Properties::anchor (Gtk::ANCHOR_SE)
+        << Gnome::Canvas::Properties::clip (true)
+        << Gnome::Canvas::Properties::clip_width (50.0)
+        << Gnome::Canvas::Properties::clip_height (55.0)
+        << Gnome::Canvas::Properties::x_offset (10.0)
+        << Gnome::Canvas::Properties::fill_color ("darkgreen");
 }
 
 
@@ -648,13 +663,24 @@ Primitives::setup_lines(Gnome::Canvas::Group& root)
   points.push_back(Gnome::Art::Point(374.0, 180.0));
   line = manage(new Gnome::Canvas::Line(root));
   line->property_points().set_value(points);
-  line->property_fill_color() = "blue";
-  line->property_width_pixels() = 0;
-  line->property_first_arrowhead() = true;
-  line->property_last_arrowhead() = true;
-  line->property_arrow_shape_a() = 6.0;
-  line->property_arrow_shape_b() = 6.0;
-  line->property_arrow_shape_c() = 4.0;
+
+//   line->property_fill_color() = "blue";
+//   line->property_width_pixels() = 0;
+//   line->property_first_arrowhead() = true;
+//   line->property_last_arrowhead() = true;
+//   line->property_arrow_shape_a() = 6.0;
+//   line->property_arrow_shape_b() = 6.0;
+//   line->property_arrow_shape_c() = 4.0;
+
+  // example for setting values using the properties mechanism
+  *line << Gnome::Canvas::Properties::fill_color ("blue")
+        << Gnome::Canvas::Properties::width_pixels (0)
+        << Gnome::Canvas::Properties::first_arrowhead (true)
+        << Gnome::Canvas::Properties::last_arrowhead (true)
+        << Gnome::Canvas::Properties::arrow_shape_a (6.0)
+        << Gnome::Canvas::Properties::arrow_shape_b (6.0)
+        << Gnome::Canvas::Properties::arrow_shape_c (4.0);
+
   line->signal_event()
       .connect(bind(slot(*this, &Primitives::on_item_event), line));
 }
